@@ -6,8 +6,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ICALIMPORTER_H
-#define ICALIMPORTER_H
+#pragma once
 
 #include "akonadi-calendar_export.h"
 
@@ -21,14 +20,14 @@
  *
  * @since 4.12
  */
-namespace Akonadi {
+namespace Akonadi
+{
 class IncidenceChanger;
 
 class AKONADI_CALENDAR_EXPORT ICalImporter : public QObject
 {
     Q_OBJECT
 public:
-
     /**
      * Constructs a new ICalImporter object. Use a different ICalImporter instance for each file you want to import.
      *
@@ -89,4 +88,3 @@ private:
 };
 }
 
-#endif // ICALIMPORTER_H
