@@ -5,11 +5,11 @@
 */
 
 #include "itiphandler_p.h"
+#include "akonadicalendar_debug.h"
 #include "fetchjobcalendar.h"
 #include <KCalendarCore/Incidence>
-#include <KMessageBox>
 #include <KLocalizedString>
-#include "akonadicalendar_debug.h"
+#include <KMessageBox>
 using namespace Akonadi;
 
 ITIPHandler::Private::Private(ITIPHandlerComponentFactory *factory, ITIPHandler *qq)
@@ -22,14 +22,11 @@ ITIPHandler::Private::Private(ITIPHandlerComponentFactory *factory, ITIPHandler
     , q(qq)
 {
     m_helper->setParent(this);
-    connect(m_scheduler, &Scheduler::transactionFinished,
-            this, &ITIPHandler::Private::onSchedulerFinished);
+    connect(m_scheduler, &Scheduler::transactionFinished, this, &ITIPHandler::Private::onSchedulerFinished);
 
-    connect(m_helper, &ITIPHandlerHelper::finished,
-            this, &ITIPHandler::Private::onHelperFinished);
+    connect(m_helper, &ITIPHandlerHelper::finished, this, &ITIPHandler::Private::onHelperFinished);
 
-    connect(m_helper, &ITIPHandlerHelper::sendIncidenceModifiedMessageFinished,
-            this, &ITIPHandler::Private::onHelperModifyDialogClosed);
+    connect(m_helper, &ITIPHandlerHelper::sendIncidenceModifiedMessageFinished, this, &ITIPHandler::Private::onHelperModifyDialogClosed);
 }
 
 void ITIPHandler::Private::onSchedulerFinished(Akonadi::Scheduler::Result result, const QString &errorMessage)
@@ -62,15 +59,14 @@ void ITIPHandler::Private::onHelperFinished(Akonadi::ITIPHandlerHelper::SendResu
         MailScheduler::Result result2 = success ? MailScheduler::ResultSuccess : MailScheduler::ResultGenericError;
         finishProcessiTIPMessage(result2, i18n("Error: %1", errorMessage));
     } else {
-        Q_EMIT q->iTipMessageSent(success ? ResultSuccess : ResultError,
-                                success ? QString() : i18n("Error: %1", errorMessage));
+        Q_EMIT q->iTipMessageSent(success ? ResultSuccess : ResultError, success ? QString() : i18n("Error: %1", errorMessage));
     }
 }
 
 void ITIPHandler::Private::onCounterProposalDelegateFinished(bool success, const QString &errorMessage)
 {
-    Q_UNUSED(success);
-    Q_UNUSED(errorMessage);
+    Q_UNUSED(success)
+    Q_UNUSED(errorMessage)
     // This will be used when we make editing counter proposals async.
 }
 
@@ -81,17 +77,13 @@ void ITIPHandler::Private::onLoadFinished(bool success, const QString &errorMess
             // Harmless hack, processiTIPMessage() asserts that there's not current operation running
             // to prevent users from calling it twice.
             m_currentOperation = OperationNone;
-            q->processiTIPMessage(m_queuedInvitation.receiver,
-                                  m_queuedInvitation.iCal,
-                                  m_queuedInvitation.action);
+            q->processiTIPMessage(m_queuedInvitation.receiver, m_queuedInvitation.iCal, m_queuedInvitation.action);
         } else {
             Q_EMIT q->iTipMessageProcessed(ResultError, i18n("Error loading calendar: %1", errorMessage));
         }
     } else if (m_currentOperation == OperationSendiTIPMessage) {
-        q->sendiTIPMessage(m_queuedInvitation.method,
-                           m_queuedInvitation.incidence,
-                           m_parentWidget);
-    } else if (!success) {   //TODO
+        q->sendiTIPMessage(m_queuedInvitation.method, m_queuedInvitation.incidence, m_parentWidget);
+    } else if (!success) { // TODO
         m_calendarLoadError = true;
     }
 }
@@ -113,24 +105,22 @@ void ITIPHandler::Private::finishProcessiTIPMessage(Akonadi::MailScheduler::Resu
             // send update to all attendees
             Q_ASSERT(m_incidence);
             m_helper->setDialogParent(m_parentWidget);
-            m_helper->sendIncidenceModifiedMessage(KCalendarCore::iTIPRequest,
-                                                   KCalendarCore::Incidence::Ptr(m_incidence->clone()),
-                                                   false);
+            m_helper->sendIncidenceModifiedMessage(KCalendarCore::iTIPRequest, KCalendarCore::Incidence::Ptr(m_incidence->clone()), false);
             m_incidence.clear();
             return;
         } else {
-            //fall through
+            // fall through
         }
     }
 
-    Q_EMIT q->iTipMessageProcessed(success ? ResultSuccess : ResultError,
-                                 success ? QString() : i18n("Error: %1", errorMessage));
+    Q_EMIT q->iTipMessageProcessed(success ? ResultSuccess : ResultError, success ? QString() : i18n("Error: %1", errorMessage));
 }
 
-void ITIPHandler::Private::onHelperModifyDialogClosed(ITIPHandlerHelper::SendResult sendResult, KCalendarCore::iTIPMethod /*method*/, const KCalendarCore::Incidence::Ptr &)
+void ITIPHandler::Private::onHelperModifyDialogClosed(ITIPHandlerHelper::SendResult sendResult,
+                                                      KCalendarCore::iTIPMethod /*method*/,
+                                                      const KCalendarCore::Incidence::Ptr &)
 {
-    if (sendResult == ITIPHandlerHelper::ResultNoSendingNeeded
-        || sendResult == ITIPHandlerHelper::ResultCanceled) {
+    if (sendResult == ITIPHandlerHelper::ResultNoSendingNeeded || sendResult == ITIPHandlerHelper::ResultCanceled) {
         Q_EMIT q->iTipMessageSent(ResultSuccess, QString());
     }
 }
@@ -149,11 +139,12 @@ void ITIPHandler::Private::finishSendiTIPMessage(Akonadi::MailScheduler::Result
         }
         Q_EMIT q->iTipMessageSent(ITIPHandler::ResultSuccess, QString());
     } else {
-        const QString error = i18nc("Groupware message sending failed. "
-                                    "%2 is request/reply/add/cancel/counter/etc.",
-                                    "Unable to send the item '%1'.\nMethod: %2",
-                                    m_queuedInvitation.incidence->summary(),
-                                    KCalendarCore::ScheduleMessage::methodName(m_queuedInvitation.method));
+        const QString error = i18nc(
+            "Groupware message sending failed. "
+            "%2 is request/reply/add/cancel/counter/etc.",
+            "Unable to send the item '%1'.\nMethod: %2",
+            m_queuedInvitation.incidence->summary(),
+            KCalendarCore::ScheduleMessage::methodName(m_queuedInvitation.method));
         if (m_parentWidget) {
             KMessageBox::error(m_parentWidget, error);
         }
@@ -173,8 +164,7 @@ void ITIPHandler::Private::finishPublishInformation(Akonadi::MailScheduler::Resu
         }
         Q_EMIT q->informationPublished(ITIPHandler::ResultSuccess, QString());
     } else {
-        const QString error = i18n("Unable to publish the item '%1'",
-                                   m_queuedInvitation.incidence->summary());
+        const QString error = i18n("Unable to publish the item '%1'", m_queuedInvitation.incidence->summary());
         if (m_parentWidget) {
             KMessageBox::error(m_parentWidget, error);
         }
@@ -195,10 +185,7 @@ void ITIPHandler::Private::finishSendAsICalendar(Akonadi::MailClient::Result res
         Q_EMIT q->sentAsICalendar(ITIPHandler::ResultSuccess, QString());
     } else {
         if (m_parentWidget) {
-            KMessageBox::error(m_parentWidget,
-                               i18n("Unable to forward the item '%1'",
-                                    m_queuedInvitation.incidence->summary()),
-                               i18n("Forwarding Error"));
+            KMessageBox::error(m_parentWidget, i18n("Unable to forward the item '%1'", m_queuedInvitation.incidence->summary()), i18n("Forwarding Error"));
         }
         qCritical() << "Sent as iCalendar failed." << errorMessage;
         Q_EMIT q->sentAsICalendar(ITIPHandler::ResultError, errorMessage);
@@ -211,8 +198,7 @@ CalendarBase::Ptr ITIPHandler::Private::calendar()
 {
     if (!m_calendar) {
         FetchJobCalendar::Ptr fetchJobCalendar = FetchJobCalendar::Ptr(new FetchJobCalendar());
-        connect(fetchJobCalendar.data(), &FetchJobCalendar::loadFinished,
-                this, &Private::onLoadFinished);
+        connect(fetchJobCalendar.data(), &FetchJobCalendar::loadFinished, this, &Private::onLoadFinished);
 
         m_calendar = fetchJobCalendar;
     }
